#!/bin/bash
# 获取本机ip 192 ip
HOST_IP=$(hostname -I | awk '{for(i=1; i<NF;i++) {if($i ~/192.168/) { print $i; exit}}}')
# CRM_PORT,DWP_PORT,CRM_CLIENT_PORT
CRM_PORT=8181
DWP_PORT=8118
CRM_CLIENT_PORT=8290
check_port() {
  if [[ $1 =~ ^[0-9]+$ ]]; then
        if [ $1 -lt 49152 ] && [ $1 -gt 1023 ]; then
            return 0
        fi
  fi
  return 1
}

#是否使用默认端口
printf "是否使用默认端口:CRM:$CRM_PORT,DWP:$DWP_PORT,CRM_CLIENT:$CRM_CLIENT_PORT :[Y/N] ";
read x ;
if [ $x == "N" ]; then
  printf "设置CRM_PORT【当前8181】:"  && read CRM_PORT
  check_port $CRM_PORT || echo "CRM_PORT必须是整数范围[1024-49152]" || exit

  printf "设置DWP_PORT【当前8118】:"  && read DWP_PORT
  check_port $DWP_PORT || echo "DWP_PORT必须是整数[1024-49152]" || exit

  printf "设置CRM_CLIENT_PORT 【当前8290】:"  && read CRM_CLIENT_PORT
  check_port $CRM_CLIENT_PORT || echo "CRM_CLIENT_PORT必须是整数[1024-49152]" || exit
fi

OS_IS_LINUX='yes'
if [ $(uname -o) != "GNU/Linux" ]; then OS_IS_LINUX='no'; fi
DOCKER_YES='yes'
if [ ! $(command -v docker) ]; then DOCKER_YES='no'; fi
GIT_YES='yes'
if [ ! $(command -v git) ]; then DOCKER_YES='no'; fi
TAR_YES='yes'
if [ ! $(command -v tar) ]; then DOCKER_YES='no'; fi
AVAILABLE_MEMORY=$(free -m | awk 'NR==2{print $7}')
COMPOSE_CMD='docker-compose'
if docker --help | grep compose >/dev/null; then
  COMPOSE_CMD='docker compose'
fi
DOCKER_COMPOSE_YES='yes'
if [ ! $(command -v docker-compose) ] && [ "$COMPOSE_CMD" != 'docker compose' ]; then DOCKER_COMPOSE_YES='no'; fi
PORT_YES='yes'
if ss -tpl | grep -E "$CRM_PORT|$DWP_PORT|$CRM_CLIENT_PORT" >/dev/null; then PORT_YES='no'; fi
cat <<EOF
检查环境:
1. 是否是linux系统 $OS_IS_LINUX
2. docker $DOCKER_YES
3. git $GIT_YES
4. docker-compose/docker compose $DOCKER_COMPOSE_YES
5. tar $TAR_YES
6. 端口$CRM_PORT,$DWP_PORT,$CRM_CLIENT_PORT是否可用 $PORT_YES
8. 本机IP $HOST_IP
EOF
if echo "$TAR_YES$GIT_YES$DOCKER_COMPOSE_YES$OS_IS_LINUX$DOCKER_YES$PORT_YES" | grep no >/dev/null; then
  exit
fi
# 变量声明
ENV='dev'
for arg in "$@"; do
  if [ -n "$arg" ]; then
    ENV="$arg"
    break
  fi
done
CODE_DIR=$(pwd)/code-$ENV
BUILD_DIR=galaxy-$ENV
if [ ! -d $CODE_DIR ]; then
  mkdir -p $CODE_DIR
fi
cd $CODE_DIR
echo "下载demo代码"
curl -o data.tgz -# http://192.168.11.163/demo/code-demo-920.tgz
echo '解压缩(每1000个文件输出一个.)'
tar --checkpoint=.1000 --checkpoint-action=dot --strip-components=1 -xf data.tgz
rm -f data.tgz
echo 'storage 目录权限处理'
find ./ -type d -name 'storage' -exec chmod -R 0777 {} +
cd $CODE_DIR/crm

grep -rlZ 192.168.11.163:8118 ./ | xargs -0 sed -i "s/192.168.11.163:8118/$HOST_IP:$DWP_PORT/g"
grep -rlZ 192.168.11.163:8181 ./ | xargs -0 sed -i "s/192.168.11.163:8181/$HOST_IP:$CRM_PORT/g"
grep -rlZ 192.168.11.163:8290 ./ | xargs -0 sed -i "s/192.168.11.163:8290/$HOST_IP:$CRM_CLIENT_PORT/g"
cd $CODE_DIR/dwp/main
grep -rlZ 192.168.11.163:8118 ./ | xargs -0 sed -i "s/192.168.11.163:8118/$HOST_IP:$DWP_PORT/g"
grep -rlZ 192.168.11.163:8181 ./ | xargs -0 sed -i "s/192.168.11.163:8181/$HOST_IP:$CRM_PORT/g"
grep -rlZ 192.168.11.163:8290 ./ | xargs -0 sed -i "s/192.168.11.163:8290/$HOST_IP:$CRM_CLIENT_PORT/g"

cd $CODE_DIR/../
git clone http://gitlab.galaxy-immi.com/kunkka.wh/docker-test.git $BUILD_DIR
cd $BUILD_DIR
cat <<EOF >.env
# 环境变量env dev,test,test1,test2等区分
ENV=$ENV
# 服务宿主机的端口
PORT=$DWP_PORT
PORT_CRM=$CRM_PORT
PORT_CRM_CLIENT=$CRM_CLIENT_PORT
# 代码目录,含前后端
CODE_DIR=$CODE_DIR
JAVA_PROFILE=innerdev # java需要根据环境调整
#nacos 客户端轮询间隔
TICK_TIME=30000
EOF
echo '生成.env文件'
cat .env
echo '启动容器,检查端口是否占用'
$COMPOSE_CMD up -d

cat <<EOF
本地访问地址
http://$HOST_IP:$DWP_PORT/   DWP
http://$HOST_IP:$CRM_PORT/   CRM
安装完成！
EOF
