#!/bin/bash
# 部署所有的应用
if [ ! -d /etc/nginx/php ]; then
  mkdir /etc/nginx/php
fi

# 超时设置
cat <<EOF >/etc/nginx/conf.d/timeout.conf

    client_header_timeout 120s;
    client_body_timeout 120s;
    send_timeout 120s;

    proxy_connect_timeout 120s;
    proxy_send_timeout 120s;
    proxy_read_timeout 120s;
    fastcgi_read_timeout 120s;
EOF
# 日志设置
cat <<EOF >/etc/nginx/conf.d/logs.conf
         #Log in JSON Format
         log_format nginxlog_json escape=json '{ "timestamp": "\$time_iso8601", '
         '"remote_addr": "\$remote_addr", '
          '"body_bytes_sent": \$body_bytes_sent, '
          '"request_time": \$request_time, '
          '"response_status": \$status, '
          '"request": "\$request", '
          '"request_method": "\$request_method", '
          '"host": "\$host",'
          '"upstream_addr": "\$upstream_addr",'
          '"http_x_forwarded_for": "\$http_x_forwarded_for",'
          '"http_referrer": "\$http_referer", '
          '"http_user_agent": "\$http_user_agent", '
          '"http_version": "\$server_protocol", '
          '"nginx_access": true }';
          access_log /dev/stdout nginxlog_json;

EOF

# php7.4
cat <<EOF >/etc/nginx/php/$PHP74_HOST.conf
location ~ \.php$ {
    fastcgi_pass $PHP74_HOST:9000;
    include fastcgi_params;
    fastcgi_index  index.php;
    fastcgi_param SCRIPT_FILENAME \$document_root\$fastcgi_script_name;
}
location / {
        proxy_ignore_client_abort on;
        fastcgi_ignore_client_abort on;
        try_files \$uri \$uri/ /index.php?\$query_string;
    }

error_page   500 502 503 504  /50x.html;
location = /50x.html {
        root   /usr/share/nginx/html;
}
EOF
# php8.0
cat <<EOF >/etc/nginx/php/$PHP80_HOST.conf
  location ~ \.php$ {
      fastcgi_pass $PHP80_HOST:9000;
      include fastcgi_params;
      fastcgi_index  index.php;
      fastcgi_param SCRIPT_FILENAME \$document_root\$fastcgi_script_name;
  }
  location / {
          proxy_ignore_client_abort on;
          fastcgi_ignore_client_abort on;
          try_files \$uri \$uri/ /index.php?\$query_string;
      }
  error_page   500 502 503 504  /50x.html;
  location = /50x.html {
          root   /usr/share/nginx/html;
  }
EOF
# common-server
cat <<EOF >/etc/nginx/conf.d/common-server.conf
server {
    listen       $GALAXY_COMMON_SERVER_API_HTTP_PORT;
    server_name  localhost;
    root   /app/www/common-server/public;
    index  index.php index.html;
    include /etc/nginx/php/$PHP74_HOST.conf;
}
EOF
# crm-admin
cat <<EOF >/etc/nginx/conf.d/crm-admin.conf
server {
    listen       $OLD_CRM_ADMIN_HTTP_PORT;
    server_name  localhost;
    root   /app/www/crm-admin/public;
    index  index.php index.html;
    location ^~ /workflow/ {
        proxy_pass http://$HOST:$GALAXY_FLOW_MICROS_API_HTTP_PORT;
    }

    location ^~ /backend/ {
        proxy_pass http://$HOST:$GALAXY_FLOW_MICROS_API_HTTP_PORT;

    }
    location ^~ /administrator/ {
        proxy_pass http://$HOST:$GALAXY_MICROS_GATEWAY_API_HTTP_PORT;

    }
    location ^~ /presale/ {
        proxy_pass http://$HOST:$GALAXY_PRESALE_MICROS_API_HTTP_PORT;
    }
    location ^~ /intelligentWriting/ {
           proxy_pass http://$JAVE_INTELLIGENTWRITING_URI/intelligentWriting/;
    }
    location ^~ /business/ {
           proxy_pass http://$HOST:$GALAXY_SERVER_SITE_API_HTTP_PORT;
   }
   location ^~ /biz-platform/ {

   	  proxy_pass http://$JAVA_BIZ_PLATFORM_URI/biz-platform/;
   }
   location ~ ^/(\.user.ini|\.htaccess|\.git|\.svn|\.project|LICENSE|README.md)
   {
           return 404;
   }
   location / {
        add_header Access-Control-Allow-Origin *;
        add_header Access-Control-Allow-Headers "Origin, X-Requested-With, Content-Type, Accept";
        add_header Access-Control-Allow-Methods "GET, POST, OPTIONS";
        try_files \$uri \$uri/ /index.html;
      }

}
EOF
# crm-client
cat <<EOF >/etc/nginx/conf.d/crm-client.conf
server {
    listen       $OLD_CRM_CLIENT_HTTP_PORT;
    server_name  localhost;
    root   /app/www/crm-client;
    index  index.php index.html;

    location ^~ /backend/ {
      proxy_pass http://$HOST:$GALAXY_FLOW_MICROS_API_HTTP_PORT;
      proxy_cache_valid 404 500 503 502 200 304 10s;
    }

    location ^~ /administrator/ {
      proxy_pass http://$HOST:$GALAXY_MICROS_GATEWAY_API_HTTP_PORT;
      proxy_cache_valid 404 500 503 502 200 304 10s;
    }

    location ^~ /client-web/ {
      proxy_pass http://$JAVA_CLIENT_URI;
      proxy_set_header X-Real-PORT \$remote_port;
      proxy_set_header X-Real-IP \$remote_addr;
      proxy_set_header X-Forwarded-For \$remote_addr;
    }

    location ^~ /business/ {
      proxy_pass http://$HOST:$GALAXY_SERVER_SITE_API_HTTP_PORT/business/;
    }

    location ^~ /newsystem/ {
      proxy_pass http://$HOST:$OLD_CRM_USER_HTTP_PORT/;
    }

    #禁止访问的文件或目录
    location ~ ^/(\.user.ini|\.htaccess|\.git|\.svn|\.project|LICENSE|README.md)
    {
      return 404;
    }
    location / {
      add_header Access-Control-Allow-Origin *;
      add_header Access-Control-Allow-Headers "Origin, X-Requested-With, Content-Type, Accept";
      add_header Access-Control-Allow-Methods "GET, POST, OPTIONS";
      try_files \$uri \$uri/ /index.html;
    }
}
EOF
# crm-userinfo
cat <<EOF >/etc/nginx/conf.d/crm-userinfo.conf
server {
    listen       $OLD_CRM_USER_HTTP_PORT;
    server_name  localhost;
    root   /app/www/user-information-system;
    index  index.php index.html;
    location ^~ /backend/ {
      proxy_pass http://$HOST:$GALAXY_FLOW_MICROS_API_HTTP_PORT;
      proxy_cache_valid 404 500 503 502 200 304 10s;
    }

    location ^~ /administrator/ {
      proxy_pass http://$HOST:$GALAXY_MICROS_GATEWAY_API_HTTP_PORT;
      proxy_cache_valid 404 500 503 502 200 304 10s;
    }

    location ^~ /client-web/ {
      proxy_pass http://$JAVA_CLIENT_URI;
      proxy_set_header X-Real-PORT \$remote_port;
      proxy_set_header X-Real-IP \$remote_addr;
      proxy_set_header X-Forwarded-For \$remote_addr;
    }

    location ^~ /business/ {
      proxy_pass http://$HOST:$GALAXY_SERVER_SITE_API_HTTP_PORT/business/;
    }
   location ~ ^/(\.user.ini|\.htaccess|\.git|\.svn|\.project|LICENSE|README.md)
   {
         return 404;
   }

}
EOF
## dwp
cat <<EOF >/etc/nginx/conf.d/dwp.conf
server {
    listen       $DWP_HTTP_PORT;
    server_name  localhost;
    root   /app/www/dwp/main;
    index  index.php index.html;

   location / {
        root /app/www/dwp/main;
        index index.html;
        try_files \$uri \$uri/ /index.html;
    }

    location ^~ /subapp {
        alias /app/www/dwp/subapp;
        try_files \$uri \$uri/ /index.html;
        add_header Access-Control-Allow-Origin *;
        add_header Access-Control-Allow-Headers *;
        add_header Access-Control-Allow-Methods *;

    }

    location ^~ /subapp/userInfo/ {
        proxy_pass http://$HOST:$VUE_USERINFO_PORT/;
        proxy_set_header X-Forwarded-For \$proxy_add_x_forwarded_for;
        proxy_set_header Host \$host;
        proxy_set_header X-Real-Ip \$remote_addr;
        proxy_set_header X-Ngnix-Proxy true;

    }



    location ^~ /crm/api/ {
        proxy_pass http://$HOST:$GALAXY_MICROS_GATEWAY_API_HTTP_PORT/;
        proxy_set_header X-Forwarded-For \$proxy_add_x_forwarded_for;
        proxy_set_header X-Real-Ip \$remote_addr;
        proxy_set_header X-Ngnix-Proxy true;
    }
    location ^~ /serversitemicrosApi/ {
        proxy_pass http://$HOST:$GALAXY_SERVER_SITE_API_HTTP_PORT/;
        proxy_set_header X-Forwarded-For \$proxy_add_x_forwarded_for;
        proxy_set_header X-Real-Ip \$remote_addr;
        proxy_set_header X-Ngnix-Proxy true;
    }

    #这里一段非常恶心，建议统一整理规划一下
    location ^~ /smarterApi/ {
        rewrite ^/smarterApi/(.*)$ /api/\$1 last;
        proxy_pass http://$HOST:$GALAXY_CRM_API_HTTP_PORT;
        proxy_set_header X-Forwarded-For \$proxy_add_x_forwarded_for;
        proxy_set_header X-Real-Ip \$remote_addr;
        proxy_set_header X-Ngnix-Proxy true;
     }
    location ^~ /api/smarterApi/ {
       rewrite ^/api/smarterApi/(.*)$ /api/\$1 last;
       proxy_pass http://$HOST:$GALAXY_CRM_API_HTTP_PORT;
       proxy_set_header X-Forwarded-For \$proxy_add_x_forwarded_for;
       proxy_set_header X-Real-Ip \$remote_addr;
       proxy_set_header X-Ngnix-Proxy true;
    }


      location ^~ /earlyWarning/smartWhale/api/ {
         proxy_pass http://$HOST:$GALAXY_CRM_API_HTTP_PORT/;
         proxy_set_header X-Forwarded-For \$proxy_add_x_forwarded_for;
         proxy_set_header X-Real-Ip \$remote_addr;
         proxy_set_header X-Ngnix-Proxy true;
      }

     location ^~ /earlyWarning/ {
         rewrite ^/earlyWarning/(.*)$ /\$1 break;
         proxy_pass http://$HOST:$NOTICE_CENTER_HTTP_PORT;
         proxy_set_header X-Forwarded-For \$proxy_add_x_forwarded_for;
         proxy_set_header X-Real-Ip \$remote_addr;
         proxy_set_header X-Ngnix-Proxy true;
         proxy_set_header X-Original-URI \$request_uri;
         proxy_set_header X-Ngnix-Proxy true;
     }
    location ^~ /api/ {
         proxy_pass http://$HOST:$GALAXY_CRM_API_HTTP_PORT/;
         proxy_set_header X-Forwarded-For \$proxy_add_x_forwarded_for;
         proxy_set_header Host \$host;
         proxy_set_header X-Real-Ip \$remote_addr;
         proxy_set_header X-Ngnix-Proxy true;

      }


    location ~ .*\.(js|css)?$
    {
      root /app/www/dwp/main;
      expires 7d;
      add_header Cache-Control "public";
    }

    #禁止访问的文件或目录
    location ~ ^/(\.user.ini|\.htaccess|\.git|\.svn|\.project|LICENSE|README.md)
    {
        return 404;
    }
}
EOF
# entry
cat <<EOF >/etc/nginx/conf.d/entry.conf
server {
    listen       $GALAXY_ENTRY_API_HTTP_PORT;
    server_name  localhost;
    root   /app/www/entry/public;
    index  index.php index.html;
    include /etc/nginx/php/$PHP74_HOST.conf;
}
EOF
# flow-mircos
cat <<EOF >/etc/nginx/conf.d/flow-micros.conf
server {
    listen       $GALAXY_FLOW_MICROS_API_HTTP_PORT;
    server_name  localhost;
    root   /app/www/flow-micros/public;
    index  index.php index.html;
    include /etc/nginx/php/$PHP74_HOST.conf;

}
EOF
# galaxy-crm
cat <<EOF >/etc/nginx/conf.d/galaxy-crm.conf
server {
    listen       $GALAXY_CRM_API_HTTP_PORT;
    server_name  localhost;
    root   /app/www/galaxy-crm/public;
    index  index.php index.html;
    include /etc/nginx/php/$PHP74_HOST.conf;

}
EOF
# galaxy-workflow
cat <<EOF >/etc/nginx/conf.d/galaxy-workflow.conf
server {
    listen       $GALAXY_WORKFLOW_API_HTTP_PORT;
    server_name  localhost;
    root   /app/www/galaxy-workflow/public;
    index  index.php index.html;
    include /etc/nginx/php/$PHP74_HOST.conf;

}
EOF
# micros-gateway
cat <<EOF >/etc/nginx/conf.d/micros-gateway.conf
server {
    listen       $GALAXY_MICROS_GATEWAY_API_HTTP_PORT;
    server_name  localhost;
    root   /app/www/micros-gateway/public;
    index  index.php index.html;
    include /etc/nginx/php/$PHP74_HOST.conf;

}
EOF
# old-crm
cat <<EOF >/etc/nginx/conf.d/old-crm.conf
server {
    listen       $OLD_CRM_HTTP_PORT;
    server_name  localhost;
    root   /app/www/crm;
    index  index.php index.html;
    location ^~ /backend/ {
      proxy_pass http://$HOST:$GALAXY_FLOW_MICROS_API_HTTP_PORT;
      proxy_cache_valid 404 500 503 502 200 304 10s;
    }

    location ^~ /administrator/ {
      proxy_pass http://$HOST:$GALAXY_MICROS_GATEWAY_API_HTTP_PORT;
      proxy_cache_valid 404 500 503 502 200 304 10s;
    }

    location ^~ /client-web/ {

      proxy_pass http://$JAVA_CLIENT_URI;
      proxy_set_header X-Real-PORT \$remote_port;
      proxy_set_header X-Real-IP \$remote_addr;
      proxy_set_header X-Forwarded-For \$remote_addr;
    }

    location ^~ /business/ {
      proxy_pass http://$HOST:$GALAXY_SERVER_SITE_API_HTTP_PORT/business/;
    }
   location ^~ /consultant/ {
      # 待部署
      proxy_pass http://test.consultant.galaxy-immi.com;
    }
    location ^~ /presale/ {
      proxy_pass http://$HOST:$GALAXY_PRESALE_MICROS_API_HTTP_PORT;
    }
    #REWRITE-END
    location /{
       # add_header Access-Control-Allow-Origin *;
       # add_header Access-Control-Allow-Headers "Origin, X-Requested-With, Content-Type, Accept";
       # add_header Access-Control-Allow-Methods "GET, POST, OPTIONS";
        try_files \$uri \$uri/ /index.html;
    }
}
EOF
# presale-micros
cat <<EOF >/etc/nginx/conf.d/presale-micros.conf
server {
    listen       $GALAXY_PRESALE_MICROS_API_HTTP_PORT;
    server_name  localhost;
    root   /app/www/presale-micros/public;
    index  index.php index.html;
    include /etc/nginx/php/$PHP74_HOST.conf;

}
EOF
# server-site
cat <<EOF >/etc/nginx/conf.d/server-site.conf
server {
    listen       $GALAXY_SERVER_SITE_API_HTTP_PORT;
    server_name  localhost;
    root   /app/www/server-site/public;
    index  index.php index.html;
    include /etc/nginx/php/$PHP74_HOST.conf;
}
EOF
# user-micros
cat <<EOF >/etc/nginx/conf.d/user-micros.conf
server {
    listen       $GALAXY_USER_MICROS_API_HTTP_PORT;
    server_name  localhost;
    root   /app/www/user-micros/public;
    index  index.php index.html;

    include /etc/nginx/php/$PHP74_HOST.conf;
}
EOF
# member-micros
cat <<EOF >/etc/nginx/conf.d/member-micros.conf
server {
    listen       $GALAXY_MEMBER_API_HTTP_PORT;
    server_name  localhost;
    root   /app/www/member-micros/public;
    index  index.php index.html;

    include /etc/nginx/php/$PHP74_HOST.conf;
}
EOF
#domain-module
cat <<EOF >/etc/nginx/conf.d/domain-module.conf
server {
    listen       $DOMAIN_MODULE_HTTP_PORT;
    server_name  localhost;
    root   /app/www/domain-module/public;
    index  index.php index.html;
    include /etc/nginx/php/$PHP80_HOST.conf;
}
EOF

# vue-userinfo
cat <<EOF >/etc/nginx/conf.d/vue-userinfo.conf
server {
    listen       $VUE_USERINFO_PORT;
    server_name  localhost;
    root   /app/www/dwp/subapp/userInfo;
    index  index.php index.html;
    location ^~ /api/ {
           proxy_pass http://$HOST:$GALAXY_CRM_API_HTTP_PORT/;
           proxy_set_header X-Forwarded-For \$proxy_add_x_forwarded_for;
           proxy_set_header Host \$host;
           proxy_set_header X-Real-Ip \$remote_addr;
           proxy_set_header X-Ngnix-Proxy true;
    }
}
EOF
# smartwhale
cat <<EOF >/etc/nginx/conf.d/smartwale.conf
server
{
    listen $VUE_SMARTWALE_PORT;
    server_name localhost;

    add_header Access-Control-Allow-Headers '*';
    add_header Access-Control-Allow-Methods '*';

    #ERROR-PAGE-START  错误页配置，可以注释、删除或修改
    error_page 404 /404.html;
    error_page 502 /502.html;
    #ERROR-PAGE-END

    #REWRITE-END
    location / {
        #暂未部署
        root /app/www/smartwhale/main;
        index index.html;
        try_files \$uri \$uri/ /index.html @redirectToMain;
    }

    location @redirectToMain {
        rewrite ^(.+)$ /index.html break;
    }

    location /subapp {
        alias /app/www/smartwhale/subapp;

        try_files \$uri \$uri/ /index.html;
        add_header Access-Control-Allow-Origin *;
        add_header Access-Control-Allow-Methods *;
        add_header Access-Control-Allow-Headers *;
    }

    # 后端 登录服务  galaxy-crm/public
    location ^~ /api/ {
        proxy_pass http://$HOST:$GALAXY_CRM_API_HTTP_PORT/;
        proxy_set_header X-Forwarded-For \$proxy_add_x_forwarded_for;
        proxy_set_header Host \$host;
        proxy_set_header X-Real-Ip \$remote_addr;
        proxy_set_header X-Ngnix-Proxy true;
    }
    #禁止访问的文件或目录
    location ~ ^/(\.user.ini|\.htaccess|\.git|\.svn|\.project|LICENSE|README.md)
    {
        return 404;
    }

    #一键申请SSL证书验证目录相关设置
    location ~ \.well-known{
        allow all;
    }
}



EOF
# earlywarning
cat <<EOF >/etc/nginx/conf.d/earlywarning.conf
server
{
    listen $VUE_NOTICE_CENTER_HTTP_PORT;
    server_name localhost;
    index index.php index.html index.htm default.php default.htm default.html;
    root /app/www/smartwhale/subapp/early_warning;
    #SSL-END

    #ERROR-PAGE-START  错误页配置，可以注释、删除或修改
    error_page 404 /404.html;
    error_page 502 /502.html;
    #ERROR-PAGE-END

     location /api {
        rewrite  ^/api/(.*)$ /$1 break;
        proxy_pass http://$HOST:$NOTICE_CENTER_HTTP_PORT;
        proxy_redirect off;
        proxy_set_header X-Forwarded-For \$proxy_add_x_forwarded_for;
        proxy_set_header Host \$host;
        proxy_set_header X-Real-Ip \$remote_addr;
        proxy_set_header X-Ngnix-Proxy true;
    }

location /horizon {
        rewrite  ^/api/(.*)$ /$1 break;
        proxy_pass http://$HOST:$NOTICE_CENTER_HTTP_PORT;
        proxy_redirect off;
        proxy_set_header X-Forwarded-For \$proxy_add_x_forwarded_for;
        proxy_set_header Host \$host;
        proxy_set_header X-Real-Ip \$remote_addr;
        proxy_set_header X-Ngnix-Proxy true;
    }

location /vendor {
        rewrite  ^/api/(.*)$ /$1 break;
        proxy_pass http://$HOST:$NOTICE_CENTER_HTTP_PORT;
        proxy_redirect off;
        proxy_set_header X-Forwarded-For \$proxy_add_x_forwarded_for;
        proxy_set_header Host \$host;
        proxy_set_header X-Real-Ip \$remote_addr;
        proxy_set_header X-Ngnix-Proxy true;

    }

    #禁止访问的文件或目录
    location ~ ^/(\.user.ini|\.htaccess|\.git|\.svn|\.project|LICENSE|README.md)
    {
        return 404;
    }

    #一键申请SSL证书验证目录相关设置
    location ~ \.well-known{
        allow all;
    }

}
# 后端 php
server {
    listen $NOTICE_CENTER_HTTP_PORT;
    server_name  localhost;
    root /app/www/notice-center/public;
    index  index.php;
    include /etc/nginx/php/$PHP74_HOST.conf;
}

EOF
mkdir -p /app/env/
cat <<EOF >/app/env/.env-for-add
#部署的env全部,用来追加到 项目的.env 文件用来支持每个服务之间的调用
#用于替换掉hostFile的配置
SERVICE_BaseMicros=$HOST:1234 #缺省
SERVICE_MarketMicros=$HOST:1234 #缺省
SERVICE_FlowMicros=$HOST:$GALAXY_FLOW_MICROS_API_HTTP_PORT
SERVICE_UserMicros=$HOST:$GALAXY_USER_MICROS_API_HTTP_PORT
SERVICE_FlowEngineMicros=$JAVA_FLOWENGINE_URI:80
SERVICE_ServerSiteMicros=$HOST:$GALAXY_SERVER_SITE_API_HTTP_PORT
SERVICE_NoticeMicros=$JAVA_NOTICE_URI:80
SERVICE_PromotionMicros=$HOST:1234#缺省
SERVICE_MemberMicros=$HOST:$GALAXY_MEMBER_API_HTTP_PORT#缺省
SERVICE_PresaleMicros=$HOST:$GALAXY_PRESALE_MICROS_API_HTTP_PORT
SERVICE_BizPlatform=$JAVA_BIZ_PLATFORM_URI:80
SERVICE_CrmClient=$JAVA_CLIENT_URI:80
SERVICE_COMMON_SERVER=$HOST:$GALAXY_COMMON_SERVER_API_HTTP_PORT
SERVICE_WORKFLOW_SERVER=$HOST:$GALAXY_WORKFLOW_API_HTTP_PORT
SERVICE_DATA_CENTER=https://dw-admin.galaxy-immi.com:443
EOF
# 针对micros-gateway生成指定的ip
cat <<EOL >/app/env/.env-gateway
USER_MODULE_URL=$HOST:$GALAXY_USER_MICROS_API_HTTP_PORT
BACKEND_MODULE_URL=$HOST:$GALAXY_FLOW_MICROS_API_HTTP_PORT
BUSINESS_MODULE_URL=$HOST:$GALAXY_SERVER_SITE_API_HTTP_PORT
ADMINISTRATOR_MODULE_URL=$HOST:$GALAXY_USER_MICROS_API_HTTP_PORT
CONSULTANT_MODULE_URL=$HOST:1234#缺省
MEMBER_MODULE_URL=$HOST:$GALAXY_MEMBER_API_HTTP_PORT
PRESALE_MODULE_URL=$HOST:$GALAXY_PRESALE_MICROS_API_HTTP_PORT
WORKFLOW_MODULE_URL=$HOST:$GALAXY_FLOW_MICROS_API_HTTP_PORT
EOL

exec "$@"